@@ -15,6 +15,8 @@ Metadata DAG function builder
 from airflow import DAG
 from openmetadata.workflows.ingestion.common import (
     build_dag,
+    build_source,
+    build_workflow_config_property,
     metadata_ingestion_workflow,
 )
 
@@ -29,7 +31,6 @@ from metadata.generated.schema.entity.services.ingestionPipelines.ingestionPipel
 from metadata.generated.schema.metadataIngestion.workflow import (
     OpenMetadataWorkflowConfig,
     Sink,
-    WorkflowConfig,
 )
 
 
@@ -39,15 +40,14 @@ def build_metadata_workflow_config(
     """
     Given an airflow_pipeline, prepare the workflow config JSON
     """
+
     workflow_config = OpenMetadataWorkflowConfig(
-        source=ingestion_pipeline.source,
+        source=build_source(ingestion_pipeline),
         sink=Sink(
             type="metadata-rest",
             config={},
         ),
-        workflowConfig=WorkflowConfig(
-            openMetadataServerConfig=ingestion_pipeline.openMetadataServerConnection
-        ),
+        workflowConfig=build_workflow_config_property(ingestion_pipeline),
     )
 
     return workflow_config
